@@ -22,18 +22,29 @@
 #include "dialogs.h"
 
 /* Variables used in the selection of the presume protocol */
+#ifdef ENABLE_SSL
+#define NUM_PRESUME_PROTOCOLS 4
+#else
 #define NUM_PRESUME_PROTOCOLS 3
+#endif
+
 
 static Protocol presume_protocol[NUM_PRESUME_PROTOCOLS] = {
     PROTOCOL_NONE,
     PROTOCOL_HTTP,
-    PROTOCOL_FTP
+    PROTOCOL_FTP,
+#ifdef ENABLE_SSL
+    PROTOCOL_HTTPS
+#endif
 };
 
 static gchar *presume_protocol_label[NUM_PRESUME_PROTOCOLS] = {
     N_ ("None"),
     N_ ("HTTP"),
-    N_ ("FTP")
+    N_ ("FTP"),
+#ifdef ENABLE_SSL
+    N_ ("HTTPS")
+#endif
 };
 
 
@@ -170,6 +181,8 @@ create_download_page (PropDialogData *prop)
                 GTK_TOGGLE_BUTTON (prop->presume_protocol[i]), TRUE);
             break;
         }
+	gtk_toggle_button_set_active (
+	    GTK_TOGGLE_BUTTON (prop->presume_protocol[PROTOCOL_NONE]), TRUE);
     }
 
     /* Connect the signal that acknowledges the change on the widget to 
