@@ -19,6 +19,8 @@
 #ifndef _GTM_APPLET_H
 #define _GTM_APPLET_H
 
+#include <config.h>
+
 /* Applet commands */
 typedef enum {
     GTM_ACTION_NONE,
@@ -36,7 +38,8 @@ typedef enum {
 typedef enum {
     PROTOCOL_NONE,
     PROTOCOL_HTTP,
-    PROTOCOL_FTP
+    PROTOCOL_FTP,
+    PROTOCOL_HTTPS
 } Protocol;
 
 typedef struct 
