@@ -54,37 +54,43 @@ ok_add_files (GtkWidget *widget, NewDlData *new_dl_data)
     /* Get the download policy info from the widgets */
     get_dl_policy_data (&dl_policy, &(new_dl_data->dl_policy));
 
+    /* Check the download policy data */
+    if (!download_policy_check (&dl_policy, new_dl_data->dlg))
+        return;
+
     /* Add the URL from the url list to the file list */
     pos = 0;
     error_msg = g_strconcat (_ ("URL:\n"), NULL);
     while ((url = (gchar *)
             gtk_clist_get_row_data (GTK_CLIST (new_dl_data->url_list),
                                     pos++)) != NULL) {
+	gint add_result;
         /* Create the file data with the information */
         file_data = dl_policy_file_data_create (url, &dl_policy);
 
         /* Add the new download file to the file list (if not a duplicate) */
-        if (!file_list_single_add (GTK_CLIST (dl_file_list), file_data)) {
-            /* URL on the file list */
-            error_msg = g_strconcat (error_msg, url, "\n", NULL);
+	add_result = file_list_single_add (GTK_CLIST (dl_file_list),
+					   file_data);
+        if (add_result != ADD_OK) {
+	    if (add_result == ADD_FAIL_DUPLICATE)
+		error_msg = g_strconcat (error_msg, url, "\n", NULL);
             file_data_free (file_data);
         }
     }
 
-    /* If there where errors give them to the user */
+    /* If there were errors give them to the user */
     if (strcmp (error_msg, _("URL:\n")) != 0) {
         GtkWidget *error;
             
         error_msg = g_strconcat (error_msg, _ ("already in the list"),
                                  NULL);
-        error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
-                                       GNOME_STOCK_BUTTON_OK, NULL);
-        /* FIXME?: Shouldn't this be parented? */
+        error = gnome_error_dialog_parented (
+            error_msg, GTK_WINDOW (new_dl_data->dlg));
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
     }
 
     /* If dialog changes default download dir update the def dl dir */
-    change_default_download_dir (dl_policy.download_dir);
+    change_default_download_dir (&dl_policy);
 
     /* Destroy the dialog box and free unused that */
     gtk_widget_destroy (new_dl_data->dlg);
@@ -201,7 +207,7 @@ static void
 dialog_add_contents (NewDlData *new_dl_data, gchar *uri_list)
 {
     GtkWidget *label, *sw;
-    gchar *initial_download_dir, *dir;
+
     /* URLs */
     label = gtk_label_new (_ ("URLs to be added"));
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
@@ -217,15 +223,7 @@ dialog_add_contents (NewDlData *new_dl_data, gchar *uri_list)
                         sw, TRUE, TRUE, 0);
 
     /* Download Policy */
-    /* FIXME: this assumes only zero or one URI in uri_list */
-    if (download_dirs_suggest_dir (uri_list, &dir))
-	initial_download_dir = dir;
-    else
-	initial_download_dir = gtm_pref.def_download_dir;
-    add_download_policy_widget (new_dl_data->dlg,
-                                &(new_dl_data->dl_policy),
-				initial_download_dir,
-				NULL, NULL);
+    add_download_policy_widget (new_dl_data->dlg, &(new_dl_data->dl_policy));
 }
 
 
@@ -266,6 +264,7 @@ dialog_add (gchar *uri_list)
         urls = url_list_build (uri_list);
         error_msg = g_strconcat (_ ("URL:\n"), NULL);
         for (p_url = urls; p_url; p_url = g_list_next (p_url)) {
+	    gint add_result;
             /* Create the file data with the information */
             file_data = file_data_create (p_url->data,
                                           "",
@@ -273,10 +272,12 @@ dialog_add (gchar *uri_list)
 
             /* Add the new download file to the file list
 	     * (if not a duplicate) */
-            if (!file_list_single_add (GTK_CLIST (dl_file_list), file_data)) {
-                /* URL on the file list */
-                error_msg = g_strconcat (error_msg,
-                                         p_url->data, "\n", NULL);
+	    add_result = file_list_single_add (GTK_CLIST (dl_file_list),
+					       file_data);
+            if (add_result != ADD_OK) {
+		if (add_result == ADD_FAIL_DUPLICATE)
+		    error_msg = g_strconcat (error_msg,
+					     p_url->data, "\n", NULL);
                 file_data_free (file_data);
             }
         }
@@ -287,8 +288,8 @@ dialog_add (gchar *uri_list)
 
             error_msg = g_strconcat (error_msg, _ ("already in the list"),
                                      NULL);
-            error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
-                                           GNOME_STOCK_BUTTON_OK, NULL);
+            error = gnome_error_dialog_parented (
+                error_msg, GTK_WINDOW (gtm_app));
             gnome_dialog_run_and_close (GNOME_DIALOG (error));
         }
 
