@@ -32,47 +32,44 @@ static GtkTargetEntry private_target_table[] = {
     { "text/plain", 0, 0 },
     { "x-url/http", 0, 0 },
     { "x-url/ftp", 0, 0 },
+#ifdef ENABLE_SSL
+    { "x-url/https", 0, 0 },
+#endif
     { "_NETSCAPE_URL", 0, 0 }
 };
 
-void
-add_download_policy_widget (GtkWidget *dlg, DlPolicyWidgets *widgets,
-			    gchar *initial_download_dir,
-                            GtkSignalFunc match_handler, void *data)
+/* Call back function used when the override download dir is changed to
+ * change the sensitivity of download dir text box */
+static void
+override_dd_cb (GtkWidget *widget, DlPolicyWidgets *widgets)
 {
-    GtkWidget *hbox, *label, *file_entry, *match_button;
+    gtk_widget_set_sensitive (widgets->download_dir,
+                              gtk_toggle_button_get_active (
+                                  GTK_TOGGLE_BUTTON (widgets->override_dd)));
+}
+
+void
+add_download_policy_widget (GtkWidget *dlg, DlPolicyWidgets *widgets)
+{
+    GtkWidget *hbox, *gtk_entry;
+    
+    /* Download directory override */
+    widgets->override_dd =
+        gtk_check_button_new_with_label (_ ("Override Download dir"));
+    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox),
+                        widgets->override_dd, FALSE, FALSE, 0);
 
     /* Download directory */
-    label = gtk_label_new (_ ("Download dir:"));
-    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox), 
-                        label, FALSE, FALSE, 0);
-    file_entry = gnome_file_entry_new ("NewDownloadDir", 
-                                       _ ("Download Dir"));
-    widgets->download_dir = 
-	gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (file_entry));
-    gnome_file_entry_set_directory (GNOME_FILE_ENTRY (file_entry), 1);
-    gtk_entry_set_text (GTK_ENTRY (widgets->download_dir), 
-                        initial_download_dir);
+    widgets->download_dir = gnome_file_entry_new ("NewDownloadDir", 
+                                                  _ ("New Download Dir"));
+    gtk_entry =
+        gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (widgets->download_dir));
+    gnome_file_entry_set_directory (GNOME_FILE_ENTRY (widgets->download_dir),
+                                    1);
+    gtk_entry_set_text (GTK_ENTRY (gtk_entry), gnome_util_user_home ());
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox),
-                        file_entry, FALSE, FALSE, 0);
-
-    if (match_handler != NULL) {
-        /* match button, only show if user has defined some rules */
-	if (download_dirs_get_total_dirs() > 0) {
-	    match_button = gtk_button_new_with_label 
-		(_ ("Suggest directory by pattern matching"));
-	    hbox = gtk_hbox_new(FALSE, FALSE);
-	    gtk_box_pack_start (GTK_BOX (hbox), match_button,
-				TRUE, FALSE, 0);
-	    gtk_box_pack_start
-		(GTK_BOX (GNOME_DIALOG (dlg)->vbox),
-		 hbox, FALSE, FALSE, 0);
-	    gtk_signal_connect (GTK_OBJECT (match_button), 
-				"clicked", 
-				GTK_SIGNAL_FUNC (match_handler),
-				(gpointer) data);
-	}
-    }
+                        widgets->download_dir, FALSE, FALSE, 0);
+    gtk_widget_set_sensitive (widgets->download_dir, FALSE);
 
     /* Download policy checkboxes */
     hbox = gtk_hbox_new (FALSE, FALSE);
@@ -94,14 +91,27 @@ add_download_policy_widget (GtkWidget *dlg, DlPolicyWidgets *widgets,
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox),
                         hbox, FALSE, FALSE, 0);
 
+    /* Set the signal handlers */
+    gtk_signal_connect (GTK_OBJECT (widgets->override_dd), "toggled", 
+                        GTK_SIGNAL_FUNC (override_dd_cb),
+                        (gpointer) widgets);
 }
 
 void
 get_dl_policy_data (DlPolicyData *data, DlPolicyWidgets *widgets)
 {
+    GtkWidget *gtk_entry;
+
+    /* Get download directory override */
+    data->override_dd =
+        gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
+            widgets->override_dd));
+
     /* Get download directory data */
+    gtk_entry =
+        gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (widgets->download_dir));
     data->download_dir =
-        gtk_entry_get_text (GTK_ENTRY (widgets->download_dir));
+        gtk_entry_get_text (GTK_ENTRY (gtk_entry));
 
     /* Get the use proxy option data */
     data->use_proxy =
@@ -117,8 +127,19 @@ get_dl_policy_data (DlPolicyData *data, DlPolicyWidgets *widgets)
 FileData *
 dl_policy_file_data_create (gchar *url, DlPolicyData *data)
 {
-    return file_data_create (url, data->download_dir, data->use_proxy,
-                             data->use_auto_dl);
+    if (data->override_dd)
+        return file_data_create (url, data->download_dir, data->use_proxy,
+                                 data->use_auto_dl);
+    else {
+	gchar *dir = NULL;
+
+        download_dirs_suggest_dir (url, &dir);
+	
+	if (dir == NULL)
+            dir = gtm_pref.def_download_dir;
+
+        return file_data_create (url, dir, data->use_proxy, data->use_auto_dl);
+    }
 }
 
 gchar *
@@ -135,12 +156,12 @@ download_dir_canonical_dup (gchar *download_dir)
 
 /* If download dialog changes default download dir update the def dl dir */
 void
-change_default_download_dir (gchar *download_dir)
+change_default_download_dir (DlPolicyData *data)
 {
-    if (gtm_pref.addnew_changes_def_dl_dir) {
+    if (gtm_pref.addnew_changes_def_dl_dir && data->override_dd) {
         g_free (gtm_pref.def_download_dir);
 	gtm_pref.def_download_dir =
-            download_dir_canonical_dup (download_dir);
+            download_dir_canonical_dup (data->download_dir);
     }
 }
 
@@ -183,17 +204,23 @@ configure_ok_cancel_dialog (GnomeDialog *dlg,
     gnome_dialog_button_connect (dlg, GNOME_CANCEL, cancel_callback, data);
 }
 
-void
-dir_suggested_check (gchar *dir, DlPolicyWidgets *dl_policy, GtkWidget *dlg)
+gboolean
+download_policy_check (DlPolicyData *data, GtkWidget *dlg)
 {
     GtkWidget *error;
 
-    if (dir == NULL) {
-        error = gnome_error_dialog_parented (_ ("No directory matched."),
+    g_return_val_if_fail (data != NULL, FALSE);
+    g_return_val_if_fail (dlg != NULL, FALSE);
+
+    /* TODO: Check directory is valid instead of non-null */
+    if (data->override_dd && strlen (data->download_dir) == 0) {
+        error = gnome_error_dialog_parented (_ ("No override download "
+                                                "directory entered."),
                                              GTK_WINDOW (dlg));
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
+        return FALSE;
     } else {
-        gtk_entry_set_text (GTK_ENTRY (dl_policy->download_dir), dir);
+	return TRUE;
     }
 }
 
@@ -201,7 +228,12 @@ gboolean
 download_not_dir_check (gchar *url, GtkWidget *dlg)
 {
     GtkWidget *error;
-    gchar *filename = get_filename (url);
+    gchar *filename;
+
+    g_return_val_if_fail (url != NULL, FALSE);
+    g_return_val_if_fail (dlg != NULL, FALSE);
+
+    filename = get_filename (url);
 
     /* TODO: If filename == NULL instead of reminding the user that it is not
      * possible yet to do multiple downloads, when the group stuff is 
