@@ -169,6 +169,10 @@ ok_num_down (GtkWidget *widget, NumDownData *num_down_data)
     /* Get the download policy info from the widgets */
     get_dl_policy_data (&dl_policy, &(num_down_data->dl_policy));
 
+    /* Check the download policy data */
+    if (!download_policy_check (&dl_policy, num_down_data->dlg))
+        return;
+
     /* Get the URL info from the widgets */
     get_url_data (&url_data, num_down_data);
 
@@ -217,7 +221,7 @@ ok_num_down (GtkWidget *widget, NumDownData *num_down_data)
     }
 
     /* If dialog changes default download dir update the def dl dir */
-    change_default_download_dir (dl_policy.download_dir);
+    change_default_download_dir (&dl_policy);
 
     /* Destroy the dialog box and free unused that */
     gtk_widget_destroy (num_down_data->dlg);
@@ -237,76 +241,6 @@ cancel_num_down (GtkWidget *widget, NumDownData *num_down_data)
     g_free (num_down_data);
 }
 
-/* Suggests a directory for a specific URL */
-static gchar *
-suggest_dir (URLData *url_data, gint num)
-{
-    gchar *url;
-    gchar *dir;
-
-    g_return_val_if_fail (url_data != NULL, NULL);
-
-    url = form_url (url_data, num);
-
-    dir = NULL;
-    download_dirs_suggest_dir (url, &dir);
-
-    g_free (url);
-
-    return dir;
-}
-
-/* If possible, calculate the directory by applying pattern matching
-   to the URL */
-static void
-match_cb (GtkWidget *widget, NumDownData *num_down_data)
-{
-    gint     num;
-    URLData  url_data;
-    gchar    *dir;
-    gchar    *this_dir;
-    gboolean success;
-    GtkWidget *error;
-
-    g_return_if_fail (widget != NULL);
-    g_return_if_fail (num_down_data != NULL);
-
-    get_url_data (&url_data, num_down_data);
-
-    /* Check URLs are valid */
-    if (!valid_urls_check (&url_data, num_down_data->dlg))
-        return;
-
-    dir = suggest_dir (&url_data, url_data.min_num);
-
-    for (num = (url_data.min_num + 1); num <= url_data.max_num; num++) {
-        this_dir = suggest_dir (&url_data, num);
-
-	success = ((this_dir == NULL) == (dir == NULL));
-
-	if (success && this_dir != NULL && dir != NULL )
-	    success = (g_strcasecmp (this_dir, dir) == 0);
-
-        if (this_dir != NULL)
-            g_free (this_dir);
-
-	if (!success) {
-            if (dir != NULL)
-                g_free (dir);
-
-            error = gnome_error_dialog_parented (_ ("Can't suggest directory "
-                                                 "as it would not be the same "
-                                                 "for all URLs."),
-                                              GTK_WINDOW (num_down_data->dlg));
-            gnome_dialog_run_and_close (GNOME_DIALOG (error));
-            return;
-	}
-    }
-
-    dir_suggested_check (dir, &(num_down_data->dl_policy),
-                         num_down_data->dlg);
-}
-
 /* Call back function used when a URL is dropped onto the dialog */
 static void
 dialog_drag_data_received (GtkWidget *widget, GdkDragContext *context,
@@ -327,15 +261,36 @@ dialog_numdown_contents (NumDownData *num_down_data)
 {
     GtkWidget *label, *hbox1, *hbox2;
     GtkObject *adjustment;
+    gchar *default_protocol;
 
     g_return_if_fail (num_down_data != NULL);
 
+    switch (gtm_pref.presume_protocol) {
+        case 0:
+            default_protocol = g_strconcat("", NULL);
+            break;
+        case 1:
+            default_protocol = g_strconcat("http://", NULL);
+            break;
+        case 2:
+            default_protocol = g_strconcat("ftp://", NULL);
+            break;
+#ifdef ENABLE_SSL
+        case 3:
+	    default_protocol = g_strconcat("https://", NULL);
+	    break;
+#endif
+        default:
+            default_protocol = g_strconcat("", NULL);
+    }
+
     /* Pre-URL */
     label = gtk_label_new (_ ("Part of URL before number:"));
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (num_down_data->dlg)->vbox), 
                         label, FALSE, FALSE, 0);
     num_down_data->pre_url = gtk_entry_new ();
     gtk_widget_set_usize (num_down_data->pre_url, 300, -2);
+    gtk_entry_set_text (GTK_ENTRY (num_down_data->pre_url), default_protocol);
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (num_down_data->dlg)->vbox), 
                         num_down_data->pre_url, FALSE, FALSE, 0);
     gtk_widget_grab_focus (num_down_data->pre_url);
@@ -404,10 +359,7 @@ dialog_numdown_contents (NumDownData *num_down_data)
 
     /* Download Policy */
     add_download_policy_widget (num_down_data->dlg,
-                                &(num_down_data->dl_policy),
-				gtm_pref.def_download_dir,
-                                GTK_SIGNAL_FUNC(match_cb),
-                                num_down_data);
+                                &(num_down_data->dl_policy));
 }
 
 /* Dialog used to add a numeric download */
