@@ -41,18 +41,28 @@ static gchar *toolbar_type_label[NUM_TOOLBAR_TYPES] = {
 };
 
 /* Variables used in the selection of the presume protocol */
+#ifdef ENABLE_SSL
+#define NUM_PRESUME_PROTOCOLS 4
+#else
 #define NUM_PRESUME_PROTOCOLS 3
+#endif
 
 static Protocol presume_protocol[NUM_PRESUME_PROTOCOLS] = {
     PROTOCOL_NONE,
     PROTOCOL_HTTP,
-    PROTOCOL_FTP
+    PROTOCOL_FTP,
+#ifdef ENABLE_SSL
+    PROTOCOL_HTTPS
+#endif
 };
 
 static gchar *presume_protocol_label[NUM_PRESUME_PROTOCOLS] = {
     N_ ("None"),
     N_ ("HTTP"),
-    N_ ("FTP")
+    N_ ("FTP"),
+#ifdef ENABLE_SSL
+    N_ ("HTTPS")
+#endif
 };
 
 
@@ -65,15 +75,18 @@ typedef struct
     GtkWidget *proxy_pass;                      /* Entry */
     GtkWidget *proxy_http;                      /* Entry */
     GtkWidget *proxy_ftp;                       /* Entry */
+    GtkWidget *proxy_https;                     /* Entry */
     GtkWidget *interface;                       /* Entry */
     GtkWidget *chk_interf_time;                 /* Spin */
     GtkWidget *simul;                           /* Spin */
     GtkWidget *def_download_dir;                /* Entry */
     GtkWidget *file_list_refresh;               /* Spin */
+    GtkWidget *read_timeout;                    /* Spin */
     GtkWidget *unlim_retries;                   /* Toggle button */
     GtkWidget *num_retries;                     /* Spin */
     GtkWidget *use_passive_ftp;                 /* Toggle button */
     GtkWidget *toolbar_type[NUM_TOOLBAR_TYPES]; /* Toggle button */
+    GtkWidget *command_all_complete;            /* Entry */
     GtkWidget *addnew_changes_def_dl_dir;       /* Toggle button */
     GtkWidget *show_list_stat;                  /* Toggle button */
     GtkWidget *show_page_stat;                  /* Toggle button */
@@ -113,6 +126,11 @@ apply_prefs_proxy (PrefDialogData *pref)
     gtm_pref.proxy_ftp = 
         g_strdup (gtk_entry_get_text (GTK_ENTRY (pref->proxy_ftp)));
     gnome_config_private_set_string ("proxy_ftp", gtm_pref.proxy_ftp);
+#ifdef ENABLE_SSL
+    gtm_pref.proxy_https = 
+        g_strdup (gtk_entry_get_text (GTK_ENTRY (pref->proxy_https)));
+    gnome_config_private_set_string ("proxy_https", gtm_pref.proxy_https);
+#endif
 }
 
 static void
@@ -168,6 +186,11 @@ apply_prefs_download (PrefDialogData *pref)
     gnome_config_set_string ("def_download_dir", 
                              gtm_pref.def_download_dir);
 
+    /* Read timeout */
+    gtm_pref.read_timeout = gtk_spin_button_get_value_as_int (
+	GTK_SPIN_BUTTON (pref->read_timeout));
+    gnome_config_set_int ("read_timeout", gtm_pref.read_timeout);
+
     /* Number of retries */
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
         pref->unlim_retries)))
@@ -191,6 +214,14 @@ apply_prefs_download (PrefDialogData *pref)
             break;
         }
     }
+
+    /* Command to run when all completed */
+    gtm_pref.command_all_complete =
+        g_strdup (gtk_entry_get_text 
+		  (GTK_ENTRY (pref->command_all_complete)));
+    gnome_config_set_string ("command_all_complete", 
+			     gtm_pref.command_all_complete);
+
     gnome_config_set_int ("presume_protocol", gtm_pref.presume_protocol);
 }
 
@@ -351,6 +382,8 @@ destroy_prefbox (GtkWidget *widget, PrefDialogData **pref)
 static void
 pref_modified_cb (GtkWidget *widget, PrefDialogData *pref)
 {
+    gboolean toggle_state;
+
     /* Change the sensitivity of the spin containing the number of retries */
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pref->unlim_retries)))
         gtk_widget_set_sensitive (pref->num_retries, FALSE);
@@ -358,17 +391,15 @@ pref_modified_cb (GtkWidget *widget, PrefDialogData *pref)
         gtk_widget_set_sensitive (pref->num_retries, TRUE);
 
     /* Change the sensitivity of the proxy preferences */
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pref->use_proxy))) {
-        gtk_widget_set_sensitive (pref->proxy_user, TRUE);
-        gtk_widget_set_sensitive (pref->proxy_pass, TRUE);
-        gtk_widget_set_sensitive (pref->proxy_http, TRUE);
-        gtk_widget_set_sensitive (pref->proxy_ftp, TRUE);
-    } else {
-        gtk_widget_set_sensitive (pref->proxy_user, FALSE);
-        gtk_widget_set_sensitive (pref->proxy_pass, FALSE);
-        gtk_widget_set_sensitive (pref->proxy_http, FALSE);
-        gtk_widget_set_sensitive (pref->proxy_ftp, FALSE);
-    }
+    toggle_state = gtk_toggle_button_get_active 
+	(GTK_TOGGLE_BUTTON (pref->use_proxy));
+    gtk_widget_set_sensitive (pref->proxy_user, toggle_state);
+    gtk_widget_set_sensitive (pref->proxy_pass, toggle_state);
+    gtk_widget_set_sensitive (pref->proxy_http, toggle_state);
+    gtk_widget_set_sensitive (pref->proxy_ftp, toggle_state);
+#ifdef ENABLE_SSL
+    gtk_widget_set_sensitive (pref->proxy_https, toggle_state);
+#endif
 
     /* Change the sensitivity of the auto hide download info page timeout */
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
@@ -382,13 +413,19 @@ pref_modified_cb (GtkWidget *widget, PrefDialogData *pref)
     gnome_property_box_changed (GNOME_PROPERTY_BOX (pref->pbox));
 }
 
+static void
+run_now_cb (GtkWidget *widget, PrefDialogData *pref)
+{
+    shell_command (gtk_entry_get_text 
+		   (GTK_ENTRY (pref->command_all_complete)));
+}
 
 /* Functions to create notebook page and set it's contents to the program
  * current preferences */
 static GtkWidget *
 create_proxy_page (PrefDialogData *pref)
 {
-    GtkWidget *vbox, *hbox, *label;
+    GtkWidget *vbox, *label, *table;
 
     /* Create vbox for page lines */
     vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
@@ -399,38 +436,61 @@ create_proxy_page (PrefDialogData *pref)
     gtk_box_pack_start (GTK_BOX (vbox), pref->use_proxy, 
                         FALSE, FALSE, 0);
 
+    /* Table to contain proxy info */
+    table = gtk_table_new (5, 2, FALSE);
+    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
+    
     /* Proxy username */
-    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     label = gtk_label_new (_ ("Username:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), label,
+		      0, 1, 0, 1, GTK_FILL, 0, 0, 0);
     pref->proxy_user = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), pref->proxy_user, FALSE, FALSE, 0);
+    gtk_table_attach (GTK_TABLE (table), pref->proxy_user,
+		      1, 2, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0);
 
     /* Proxy password */
-    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     label = gtk_label_new (_ ("Password:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), label,
+		      0, 1, 1, 2, GTK_FILL, 0, 0, 0);
     pref->proxy_pass = gtk_entry_new ();
     gtk_entry_set_visibility (GTK_ENTRY (pref->proxy_pass), FALSE);
-    gtk_box_pack_start (GTK_BOX (hbox), pref->proxy_pass, FALSE, FALSE, 0);
+    gtk_table_attach (GTK_TABLE (table), pref->proxy_pass,
+		      1, 2, 1, 2, GTK_EXPAND|GTK_FILL, 0, 0, 0);
 
     /* Proxy for HTTP */
-    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     label = gtk_label_new (_ ("HTTP:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), label,
+		      0, 1, 2, 3, GTK_FILL, 0, 0, 0);
     pref->proxy_http = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), pref->proxy_http, TRUE, TRUE, 0);
+    gtk_table_attach (GTK_TABLE (table), pref->proxy_http,
+		      1, 2, 2, 3, GTK_EXPAND|GTK_FILL, 0, 0, 0);
 
     /* Proxy for FTP */
-    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     label = gtk_label_new (_ ("FTP:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), label,
+		      0, 1, 3, 4, GTK_FILL, 0, 0, 0);
     pref->proxy_ftp = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), pref->proxy_ftp, TRUE, TRUE, 0);
+    gtk_table_attach (GTK_TABLE (table), pref->proxy_ftp,
+		      1, 2, 3, 4, GTK_EXPAND|GTK_FILL, 0, 0, 0);
+
+#ifdef ENABLE_SSL
+    /* Proxy for HTTPS */
+    label = gtk_label_new (_ ("HTTPS:"));
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), label,
+		      0, 1, 4, 5, GTK_FILL, 0, 0, 0);
+    pref->proxy_https = gtk_entry_new ();
+    gtk_table_attach (GTK_TABLE (table), pref->proxy_https,
+		      1, 2, 4, 5, GTK_EXPAND|GTK_FILL, 0, 0, 0);
+#endif
+
+    /* Set up table spacings */
+    gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
+    gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
     /* Set the current option */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->use_proxy),
@@ -440,6 +500,9 @@ create_proxy_page (PrefDialogData *pref)
         gtk_widget_set_sensitive (pref->proxy_pass, FALSE);
         gtk_widget_set_sensitive (pref->proxy_http, FALSE);
         gtk_widget_set_sensitive (pref->proxy_ftp, FALSE);
+#ifdef ENABLE_SSL	
+	gtk_widget_set_sensitive (pref->proxy_https, FALSE);
+#endif
     }
     gtk_entry_set_text (GTK_ENTRY (pref->proxy_user), 
                         gtm_pref.proxy_user);
@@ -449,6 +512,10 @@ create_proxy_page (PrefDialogData *pref)
                         gtm_pref.proxy_http);
     gtk_entry_set_text (GTK_ENTRY (pref->proxy_ftp), 
                         gtm_pref.proxy_ftp);
+#ifdef ENABLE_SSL
+    gtk_entry_set_text (GTK_ENTRY (pref->proxy_https), 
+                        gtm_pref.proxy_https);
+#endif
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
@@ -467,6 +534,11 @@ create_proxy_page (PrefDialogData *pref)
     gtk_signal_connect (GTK_OBJECT (pref->proxy_ftp), "changed",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
+#ifdef ENABLE_SSL
+    gtk_signal_connect (GTK_OBJECT (pref->proxy_https), "changed",
+                        GTK_SIGNAL_FUNC (pref_modified_cb),
+                        (gpointer) pref);
+#endif
 
     return vbox;
 }
@@ -527,7 +599,8 @@ create_auto_page (PrefDialogData *pref)
 
     /* Load pause auto download */
     pref->load_pause_auto_dl =
-        gtk_check_button_new_with_label (_ ("Load pause auto download state"));
+        gtk_check_button_new_with_label (_ ("Remember whether auto download "
+					    "is paused"));
     gtk_box_pack_start (GTK_BOX (vbox), pref->load_pause_auto_dl,
                         FALSE, FALSE, 0);
 
@@ -575,7 +648,7 @@ static GtkWidget *
 create_download_page (PrefDialogData *pref)
 {
     GtkWidget *vbox, *hbox, *label, *radio;
-    GtkWidget *def_download_dir;
+    GtkWidget *def_download_dir, *button;
     GtkObject *adjustment;
     GSList *group;
     guint i;
@@ -596,6 +669,17 @@ create_download_page (PrefDialogData *pref)
     gnome_file_entry_set_directory (GNOME_FILE_ENTRY (def_download_dir), 1);
     gtk_box_pack_start (GTK_BOX (hbox), def_download_dir, TRUE, TRUE, 0);
 
+    /* Read timeout */
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    label = gtk_label_new (_ ("Timeout (seconds):"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    adjustment = gtk_adjustment_new (30, 0, 3600, 1, 30, 30);
+    pref->read_timeout =
+	gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1, 0);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (pref->read_timeout), TRUE);
+    gtk_box_pack_start (GTK_BOX (hbox), pref->read_timeout, TRUE, TRUE, 0);
+
     /* Number of retries */
     hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
@@ -621,7 +705,7 @@ create_download_page (PrefDialogData *pref)
     gtk_box_pack_start (GTK_BOX (vbox), pref->use_passive_ftp, FALSE, FALSE,
                         0);
 
-    /* Toolbar style */
+    /* Presume protocol */
     hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     label = gtk_label_new (_ ("Presume Protocol:"));
@@ -638,11 +722,29 @@ create_download_page (PrefDialogData *pref)
                 pref->presume_protocol[i]));
     }
 
+    /* Shell command on completion */
+    label = gtk_label_new (_ ("Run command when all downloads completed:"));
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    pref->command_all_complete = gtk_entry_new();
+    gtk_box_pack_start (GTK_BOX (hbox), pref->command_all_complete,
+			TRUE, TRUE, 0);
+    
+    button = gtk_button_new_with_label (_ ("Run Now"));
+    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+    gtk_signal_connect (GTK_OBJECT (button), "clicked", 
+			GTK_SIGNAL_FUNC (run_now_cb),
+			(gpointer) pref);
+
     /* Set current preferences */
     gtk_entry_set_text (GTK_ENTRY (pref->def_download_dir), 
                         gtm_pref.def_download_dir);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->use_passive_ftp),
                                   gtm_pref.use_passive_ftp);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (pref->read_timeout),
+			       (gfloat) gtm_pref.read_timeout);
     if (gtm_pref.num_retries == 0) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pref->unlim_retries),
                                       TRUE);
@@ -658,13 +760,20 @@ create_download_page (PrefDialogData *pref)
                 GTK_TOGGLE_BUTTON (pref->presume_protocol[i]), TRUE);
             break;
         }
+	gtk_toggle_button_set_active (
+	    GTK_TOGGLE_BUTTON (pref->presume_protocol[PROTOCOL_NONE]), TRUE);
     }
+    gtk_entry_set_text (GTK_ENTRY (pref->command_all_complete),
+			gtm_pref.command_all_complete);
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
     gtk_signal_connect (GTK_OBJECT (pref->def_download_dir), "changed",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
+    gtk_signal_connect (GTK_OBJECT (pref->read_timeout), "changed",
+			GTK_SIGNAL_FUNC (pref_modified_cb),
+			(gpointer) pref);
     gtk_signal_connect (GTK_OBJECT (pref->use_passive_ftp), "toggled",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
@@ -677,6 +786,10 @@ create_download_page (PrefDialogData *pref)
     gtk_signal_connect (GTK_OBJECT (pref->num_retries), "changed",
                         GTK_SIGNAL_FUNC (pref_modified_cb),
                         (gpointer) pref);
+    gtk_signal_connect (GTK_OBJECT (pref->command_all_complete), "changed",
+                        GTK_SIGNAL_FUNC (pref_modified_cb),
+                        (gpointer) pref);
+    
     for (i = 0; i < NUM_PRESUME_PROTOCOLS; i++)
         gtk_signal_connect (GTK_OBJECT (pref->presume_protocol[i]), "clicked",
                             GTK_SIGNAL_FUNC (pref_modified_cb),
@@ -712,7 +825,8 @@ create_confirmations_page (PrefDialogData *pref)
     /* New changes default download dir */
     pref->addnew_changes_def_dl_dir = 
         gtk_check_button_new_with_label (_ (
-            "Dialog new or dialog add changes default download dir"));
+            "Overriding download dir on URL addition dialogs changes default "
+            "download dir"));
     gtk_box_pack_start (GTK_BOX (vbox), pref->addnew_changes_def_dl_dir, FALSE,
                         FALSE, 0);
 
