@@ -47,12 +47,12 @@ dialog_remove (void)
 
     /* If any files left ask the user if he really wants to remove the files */
     if (GTK_CLIST (dl_file_list)->selection != NULL) {
-        dlg = gnome_dialog_new (_ ("GTM - Remove selected files"), 
+        dlg = gnome_dialog_new (_ ("Remove selected files from list"), 
                                 GNOME_STOCK_BUTTON_YES, 
                                 GNOME_STOCK_BUTTON_NO, NULL);
         gnome_dialog_set_parent (GNOME_DIALOG (dlg), GTK_WINDOW (gtm_app));
         label = gtk_label_new (_ (
-            "Do you really want to remove selected files?"));
+            "Do you really want to remove selected files from the list?"));
         gtk_widget_show (label);
         gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dlg)->vbox), label, FALSE,
                             FALSE, 0);
