@@ -25,8 +25,9 @@
 #include "finish.xpm"
 #include "run.xpm"
 #include "stop.xpm"
+#include "unstarted.xpm"
 
-#define NUM_COLS 5
+#define NUM_COLS 6
 #define NUM_ROWS 6
 
 
@@ -34,6 +35,7 @@ typedef struct
 {
     GtkWidget *dlg;
     /* data labels */
+    GtkWidget *num_unstarted;
     GtkWidget *num_stopped;
     GtkWidget *num_running;
     GtkWidget *num_completed;
@@ -87,14 +89,16 @@ dialog_stats_create_data ()
 {
     GtkWidget *table, *label;
     GtkTable *t;
-    static GdkPixmap *pm_stop = NULL, *pm_run = NULL, *pm_finish = NULL;
+    static GdkPixmap *pm_stop = NULL, *pm_run = NULL, *pm_finish = NULL,
+        *pm_unstarted = NULL;
     static GdkBitmap *pm_stop_mask = NULL, *pm_run_mask = NULL,
-        *pm_finish_mask = NULL;
+        *pm_finish_mask = NULL, *pm_unstarted_mask = NULL;
 
     stats_data = g_new (SummaryData, 1);
     stats_data->dlg = 
         gnome_dialog_new (_ ("List summary"), GNOME_STOCK_BUTTON_CLOSE, NULL);
     
+    stats_data->num_unstarted = dialog_stats_create_label();
     stats_data->num_stopped = dialog_stats_create_label();
     stats_data->num_running = dialog_stats_create_label();
     stats_data->num_completed = dialog_stats_create_label();
@@ -124,17 +128,22 @@ dialog_stats_create_data ()
     gtk_table_set_col_spacings (t, 15);
 
     /* column headers */
+    gdk_imlib_data_to_pixmap (unstarted_xpm, &pm_unstarted,
+                              &pm_unstarted_mask);
+    gtk_table_attach_defaults (t, gtk_pixmap_new (pm_unstarted,
+                                                  pm_unstarted_mask),
+                               1, 2, 0, 1);
     gdk_imlib_data_to_pixmap (stop_xpm, &pm_stop, &pm_stop_mask);
     gtk_table_attach_defaults (t, gtk_pixmap_new (pm_stop, pm_stop_mask),
-                               1, 2, 0, 1);
+                               2, 3, 0, 1);
     gdk_imlib_data_to_pixmap (run_xpm, &pm_run, &pm_run_mask);
     gtk_table_attach_defaults (t, gtk_pixmap_new(pm_run, pm_run_mask), 
-                               2, 3, 0, 1);
+                               3, 4, 0, 1);
     gdk_imlib_data_to_pixmap (finish_xpm, &pm_finish, &pm_finish_mask);
     gtk_table_attach_defaults (t, gtk_pixmap_new (pm_finish, pm_finish_mask), 
-                               3, 4, 0, 1);
-    gtk_table_attach_defaults (t, gtk_label_new (_ ("Total")), 
                                4, 5, 0, 1);
+    gtk_table_attach_defaults (t, gtk_label_new (_ ("Total")), 
+                               5, 6, 0, 1);
 
     /* row labels */
     label = gtk_label_new (_ ("Number of files"));
@@ -154,43 +163,44 @@ dialog_stats_create_data ()
     gtk_table_attach_defaults (t, label, 0, 1, 5, 6);
 
     /* row: number of files */
-    gtk_table_attach_defaults (t, stats_data->num_stopped,       1, 2, 1, 2);
-    gtk_table_attach_defaults (t, stats_data->num_running,       2, 3, 1, 2);
-    gtk_table_attach_defaults (t, stats_data->num_completed,     3, 4, 1, 2);
-    gtk_table_attach_defaults (t, stats_data->num_total,         4, 5, 1, 2);
+    gtk_table_attach_defaults (t, stats_data->num_unstarted,     1, 2, 1, 2);
+    gtk_table_attach_defaults (t, stats_data->num_stopped,       2, 3, 1, 2);
+    gtk_table_attach_defaults (t, stats_data->num_running,       3, 4, 1, 2);
+    gtk_table_attach_defaults (t, stats_data->num_completed,     4, 5, 1, 2);
+    gtk_table_attach_defaults (t, stats_data->num_total,         5, 6, 1, 2);
     
     /* row: total size */
-    gtk_table_attach (t, stats_data->size_stopped,      1, 2, 2, 3,
+    gtk_table_attach (t, stats_data->size_stopped,      2, 3, 2, 3,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->size_running,      2, 3, 2, 3,
+    gtk_table_attach (t, stats_data->size_running,      3, 4, 2, 3,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->size_completed,    3, 4, 2, 3,
+    gtk_table_attach (t, stats_data->size_completed,    4, 5, 2, 3,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->size_total,        4, 5, 2, 3,
+    gtk_table_attach (t, stats_data->size_total,        5, 6, 2, 3,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
     
     /* row: retrieved */
-    gtk_table_attach (t, stats_data->retrieved_stopped, 1, 2, 3, 4,
+    gtk_table_attach (t, stats_data->retrieved_stopped, 2, 3, 3, 4,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->retrieved_running, 2, 3, 3, 4,
+    gtk_table_attach (t, stats_data->retrieved_running, 3, 4, 3, 4,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->retrieved_completed, 3, 4, 3, 4,
+    gtk_table_attach (t, stats_data->retrieved_completed, 4, 5, 3, 4,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->retrieved_total,   4, 5, 3, 4,
+    gtk_table_attach (t, stats_data->retrieved_total,   5, 6, 3, 4,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
 
     /* row: remaining */
-    gtk_table_attach (t, stats_data->remain_stopped, 1, 2, 4, 5,
+    gtk_table_attach (t, stats_data->remain_stopped, 2, 3, 4, 5,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->remain_running, 2, 3, 4, 5,
+    gtk_table_attach (t, stats_data->remain_running, 3, 4, 4, 5,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
-    gtk_table_attach (t, stats_data->remain_total,   4, 5, 4, 5,
+    gtk_table_attach (t, stats_data->remain_total,   5, 6, 4, 5,
                       GTK_EXPAND|GTK_FILL, 0, 0, 0);
     
     /* row: percent progress */
-    gtk_table_attach_defaults (t, stats_data->percent_stopped, 1, 2, 5, 6);
-    gtk_table_attach_defaults (t, stats_data->percent_running, 2, 3, 5, 6);
-    gtk_table_attach_defaults (t, stats_data->percent_total,   4, 5, 5, 6);
+    gtk_table_attach_defaults (t, stats_data->percent_stopped, 2, 3, 5, 6);
+    gtk_table_attach_defaults (t, stats_data->percent_running, 3, 4, 5, 6);
+    gtk_table_attach_defaults (t, stats_data->percent_total,   5, 6, 5, 6);
 
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (stats_data->dlg)->vbox),
                         table, FALSE, FALSE, 0);
@@ -243,6 +253,8 @@ dialog_stats_update (FileListStats *stats)
         dialog_stats_create_data();
 
     /* row: num files */
+    sprintf(buffer, "%d", stats->num_unstarted);
+    gtk_label_set_text (GTK_LABEL (stats_data->num_unstarted), buffer);
     sprintf(buffer, "%d", stats->num_stopped);
     gtk_label_set_text (GTK_LABEL (stats_data->num_stopped), buffer);
     sprintf(buffer, "%d", stats->num_running);
