@@ -33,7 +33,7 @@ void dialog_remove (void);
 
 void dialog_prefs (void);
 
-void dialog_prop (gboolean open_dialog, FileData *file_data);
+void dialog_prop (gboolean open_dialog);
 
 void dialog_add (gchar *uri_list);
 
