@@ -259,7 +259,7 @@ download_dirs_list_create (GtkWidget **dir_list) {
     GtkWidget *hbox, *vbox, *dir_list_sw;
 
     gchar *titles[] = {
-        N_ ("Pattern"),
+        N_ ("URL Pattern"),
         N_ ("Download to Directory")
     };
     gchar* t_titles[DIR_LIST_TOTAL_COLUMNS];
