@@ -30,6 +30,7 @@ typedef struct
     GtkWidget *url;              /* Label */
     GtkWidget *file;             /* Label */
     GtkWidget *size;             /* Label */
+    GtkWidget *local_dir;        /* Label */
     GtkWidget *state;            /* Label */
     GtkWidget *retr_progress;    /* ProgressBar */
     GtkWidget *retrieved;        /* Label */
@@ -39,7 +40,6 @@ typedef struct
     GtkWidget *total_speed;      /* Label */
     GtkWidget *sess_time;        /* Label */
     GtkWidget *sess_speed;       /* Label */
-    GtkWidget *local_dir;        /* Label */
     GtkWidget *use_proxy;        /* Toggle Button */
     GtkWidget *use_auto_dl;      /* Toggle Button */
 } Info;
@@ -59,11 +59,9 @@ convert_time2str (gchar *buffer, guint32 time)
 static GtkWidget *
 create_frame_location (void)
 {
-    GtkWidget *frame, *table, *label, *sw;
+    GtkWidget *table, *label, *sw;
 
-    frame = gtk_frame_new (_ ("Location"));
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    table = gtk_table_new (3, 2, FALSE);
+    table = gtk_table_new (4, 2, FALSE);
     gtk_table_set_col_spacing (GTK_TABLE (table), 0, GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (table),
                                     GNOME_PAD_SMALL);
@@ -73,7 +71,6 @@ create_frame_location (void)
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 				    GTK_POLICY_ALWAYS,
 				    GTK_POLICY_NEVER);
-    gtk_container_add (GTK_CONTAINER (frame), sw);
     
     label = gtk_label_new (_ ("Url:"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
@@ -99,7 +96,15 @@ create_frame_location (void)
     gtk_misc_set_alignment (GTK_MISC (info.size), 0.0, 0.5);
     gtk_table_attach_defaults (GTK_TABLE (table), info.size, 1, 2, 2, 3);
 
-    return frame;
+    label = gtk_label_new (_ ("Dir:"));
+    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
+                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+    info.local_dir = gtk_label_new ("");
+    gtk_misc_set_alignment (GTK_MISC (info.local_dir), 0.0, 0.5);
+    gtk_table_attach_defaults (GTK_TABLE (table), info.local_dir, 1, 2, 3, 4);
+
+    return sw;
 }
 
 static GtkWidget *
@@ -109,7 +114,7 @@ create_frame_status (void)
 
     frame = gtk_frame_new (_ ("Status"));
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-    table = gtk_table_new (5, 2, FALSE);
+    table = gtk_table_new (3, 3, FALSE);
     gtk_table_set_col_spacing (GTK_TABLE (table), 0, GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (table),
                                     GNOME_PAD_SMALL);
@@ -118,110 +123,79 @@ create_frame_status (void)
     label = gtk_label_new (_ ("State:"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+                      GTK_SHRINK | GTK_FILL, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     info.state = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.state), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.state, 1, 2, 0, 1);
-
-    label = gtk_label_new (_ ("Retrieve progress:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
-    info.retr_progress = gtk_progress_bar_new ();
-    gtk_table_attach_defaults (GTK_TABLE (table), info.retr_progress,
-                               1, 2, 1, 2);
+    gtk_table_attach (GTK_TABLE (table), info.state, 1, 3, 0, 1,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
 
     label = gtk_label_new (_ ("Retrieved:"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+                      GTK_SHRINK | GTK_FILL, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     info.retrieved = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.retrieved), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.retrieved, 1, 2, 2, 3);
+    gtk_table_attach (GTK_TABLE (table), info.retrieved, 1, 2, 1, 2,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
+    info.retr_progress = gtk_progress_bar_new ();
+    gtk_widget_set_usize (info.retr_progress, 10, 10);
+    gtk_table_attach (GTK_TABLE (table), info.retr_progress, 2, 3, 1, 2,
+                      GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+                      GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
 
-    label = gtk_label_new (_ ("Estimated:"));
+    label = gtk_label_new (_ ("Estimated/Remain:"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+                      GTK_SHRINK | GTK_FILL, 0, GNOME_PAD_SMALL, 0);
     info.estimated = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.estimated), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.estimated, 1, 2, 3, 4);
-
-    label = gtk_label_new (_ ("Remain:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+    gtk_table_attach (GTK_TABLE (table), info.estimated, 1, 2, 2, 3,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     info.remain = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.remain), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.remain, 1, 2, 4, 5);
-
+    gtk_table_attach (GTK_TABLE (table), info.remain, 2, 3, 2, 3,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     return frame;
 }
 
 static GtkWidget *
-create_frame_total (void)
+create_frame_total_sess (void)
 {
     GtkWidget *frame, *table, *label;
 
-    frame = gtk_frame_new (_ ("Total"));
+    frame = gtk_frame_new (_ ("Total/Session"));
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-    table = gtk_table_new (2, 2, FALSE);
+    table = gtk_table_new (3, 2, FALSE);
     gtk_table_set_col_spacing (GTK_TABLE (table), 0, GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (table),
                                     GNOME_PAD_SMALL);
     gtk_container_add (GTK_CONTAINER (frame), table);
     
-    label = gtk_label_new (_ ("Total time:"));
+    label = gtk_label_new (_ ("Time:"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+                      GTK_SHRINK | GTK_FILL, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     info.total_time = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.total_time), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.total_time,
-                               1, 2, 0, 1);
-
-    label = gtk_label_new (_ ("Total speed:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
-    info.total_speed = gtk_label_new ("");
-    gtk_misc_set_alignment (GTK_MISC (info.total_speed), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.total_speed,
-                               1, 2, 1, 2);
-
-    return frame;
-}
-
-static GtkWidget *
-create_frame_sess (void)
-{
-    GtkWidget *frame, *table, *label;
-
-    frame = gtk_frame_new (_ ("Session"));
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-    table = gtk_table_new (2, 2, FALSE);
-    gtk_table_set_col_spacing (GTK_TABLE (table), 0, GNOME_PAD_SMALL);
-    gtk_container_set_border_width (GTK_CONTAINER (table),
-                                    GNOME_PAD_SMALL);
-    gtk_container_add (GTK_CONTAINER (frame), table);
-    
-    label = gtk_label_new (_ ("Session time:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+    gtk_table_attach (GTK_TABLE (table), info.total_time, 1, 2, 0, 1,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     info.sess_time = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.sess_time), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.sess_time,
-                               1, 2, 0, 1);
+    gtk_table_attach (GTK_TABLE (table), info.sess_time, 2, 3, 0, 1,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
 
-    label = gtk_label_new (_ ("Session speed:"));
+    label = gtk_label_new (_ ("Speed:"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+                      GTK_SHRINK | GTK_FILL, GTK_SHRINK, GNOME_PAD_SMALL, 0);
+    info.total_speed = gtk_label_new ("");
+    gtk_misc_set_alignment (GTK_MISC (info.total_speed), 0.0, 0.5);
+    gtk_table_attach (GTK_TABLE (table), info.total_speed, 1, 2, 1, 2,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     info.sess_speed = gtk_label_new ("");
     gtk_misc_set_alignment (GTK_MISC (info.sess_speed), 0.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.sess_speed,
-                               1, 2, 1, 2);
+    gtk_table_attach (GTK_TABLE (table), info.sess_speed, 2, 3, 1, 2,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
 
     return frame;
 }
@@ -236,8 +210,6 @@ toggle_proxy_cb (GtkWidget *widget, gpointer data)
     file_data_set_use_proxy (file_data,
                              gtk_toggle_button_get_active (
                                  GTK_TOGGLE_BUTTON (info.use_proxy)));
-    download_info_update (file_data);
-    dialog_prop (FALSE, file_data);
 }
 
 static void
@@ -251,50 +223,37 @@ toggle_auto_dl_cb (GtkWidget *widget, gpointer data)
                                    gtk_toggle_button_get_active (
                                        GTK_TOGGLE_BUTTON (
                                            info.use_auto_dl)));
-    download_info_update (file_data);
-    dialog_prop (FALSE, file_data);
 }
 
 static GtkWidget *
 create_frame_options (void)
 {
-    GtkWidget *frame, *table, *label, *sw;
+    GtkWidget *frame, *table;
 
     frame = gtk_frame_new (_ ("Options"));
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-    table = gtk_table_new (3, 2, FALSE);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
+    table = gtk_table_new (1, 2, FALSE);
     gtk_table_set_col_spacing (GTK_TABLE (table), 0, GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (table),
                                     GNOME_PAD_SMALL);
-    sw = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw),
-                                           table);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-				    GTK_POLICY_ALWAYS,
-				    GTK_POLICY_NEVER);
-    gtk_container_add (GTK_CONTAINER (frame), sw);
+    gtk_container_add (GTK_CONTAINER (frame), table);
     
-    label = gtk_label_new (_ ("Local dir:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      GTK_SHRINK | GTK_FILL, 0, 0, 0);
-    info.local_dir = gtk_label_new ("");
-    gtk_misc_set_alignment (GTK_MISC (info.local_dir), 1.0, 0.5);
-    gtk_table_attach_defaults (GTK_TABLE (table), info.local_dir, 1, 2, 0, 1);
-
     info.use_proxy = gtk_check_button_new_with_label (_ ("Use proxy"));
-    gtk_table_attach_defaults (GTK_TABLE (table), info.use_proxy,
-                               0, 2, 1, 2);
+    gtk_table_attach (GTK_TABLE (table), info.use_proxy, 0, 1, 0, 1,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     gtk_signal_connect (GTK_OBJECT (info.use_proxy), "toggled", 
                         GTK_SIGNAL_FUNC (toggle_proxy_cb), NULL);
 
     info.use_auto_dl =
         gtk_check_button_new_with_label (_ ("Use auto download"));
-    gtk_table_attach_defaults (GTK_TABLE (table), info.use_auto_dl,
-                               0, 2, 2, 3);
+    gtk_table_attach (GTK_TABLE (table), info.use_auto_dl, 1, 2, 0, 1,
+                      GTK_SHRINK, GTK_SHRINK, GNOME_PAD_SMALL, 0);
     gtk_signal_connect (GTK_OBJECT (info.use_auto_dl), "toggled", 
                         GTK_SIGNAL_FUNC (toggle_auto_dl_cb), NULL);
 
+    gtk_widget_set_sensitive (GTK_WIDGET (info.use_auto_dl), FALSE);
+    gtk_widget_set_sensitive (GTK_WIDGET (info.use_proxy), FALSE);
+
     return frame;
 }
 
@@ -306,29 +265,25 @@ download_info_create (void)
     GtkWidget *table;
 
     /* Create the for the frames with information */
-    table = gtk_table_new (4, 2, FALSE);
+    table = gtk_table_new (4, 1, FALSE);
     gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
 
     /* Create the frame with location info */
-    gtk_table_attach_defaults (GTK_TABLE (table), create_frame_location (), 
-                               0, 2, 0, 1);
+    gtk_table_attach (GTK_TABLE (table), create_frame_location (), 0, 1, 0, 1,
+                      GTK_FILL, GTK_SHRINK, 0, 0);
     
     /* Create frame with status */
-    gtk_table_attach_defaults (GTK_TABLE (table), create_frame_status (),
-                               0, 2, 1, 2);
+    gtk_table_attach (GTK_TABLE (table), create_frame_status (), 0, 1, 1, 2,
+                      GTK_FILL, GTK_SHRINK, 0, 0);
 
     /* Create frame with total information */
-    gtk_table_attach_defaults (GTK_TABLE (table), create_frame_total (),
-                               0, 1, 2, 3);
-
-    /* Create frame with session information */
-    gtk_table_attach_defaults (GTK_TABLE (table), create_frame_sess (),
-                               1, 2, 2, 3);
+    gtk_table_attach (GTK_TABLE (table), create_frame_total_sess (),
+                      0, 1, 2, 3, GTK_FILL, GTK_SHRINK, 0, 0);
 
     /* Create frame with options */
-    gtk_table_attach_defaults (GTK_TABLE (table), create_frame_options (),
-                               0, 2, 3, 4);
+    gtk_table_attach (GTK_TABLE (table), create_frame_options (),
+                      0, 1, 3, 4, GTK_FILL, GTK_SHRINK, 0, 0);
 
     /* We have built everything now show it */
     gtk_widget_show_all (table);
@@ -338,20 +293,24 @@ download_info_create (void)
 
 
 /* Functions to update the download info page */
-void
+static void
 download_info_update_state (FileData *file_data)
 {
     gtk_label_set_text (GTK_LABEL (info.state),
                         file_data_state_name (file_data));
 }
 
-void
+static void
 download_info_update_total_size (FileData *file_data)
 {
     gchar buffer[20];
 
     if (file_data->state == DL_NOT_STARTED)
 	strcpy (buffer, "");
+    else if (file_data->state == DL_COMPLETED
+             && file_data->total_size == 0
+             && file_data->cur_size != 0)
+	sprintf (buffer, "%d kB", (file_data->cur_size + 512) / 1024);
     else if (file_data->total_size == 0)
 	strcpy (buffer, _ ("Unspecified"));
     else
@@ -370,7 +329,7 @@ download_info_update_total_size (FileData *file_data)
     }
 }
 
-void
+static void
 download_info_update_statistics (FileData *file_data)
 {
     gchar buffer[20];
@@ -417,7 +376,7 @@ download_info_update_statistics (FileData *file_data)
     if (file_data->state != DL_NOT_STARTED 
         && file_data->state != DL_NOT_RUNNING 
         && file_data->state != DL_COMPLETED) {
-        if (retr_size != 0)
+        if (file_data->total_size != 0 && retr_size != 0)
             estimated =
                 (((gfloat) (file_data->total_size
                             - file_data->session_start_size)
@@ -427,7 +386,8 @@ download_info_update_statistics (FileData *file_data)
         else
             estimated = 0;
     } else {
-        if (file_data->cur_size != 0 && file_data->state != DL_COMPLETED)
+        if (file_data->total_size != 0 && file_data->cur_size != 0
+            && file_data->state != DL_COMPLETED)
             estimated =
                 ((gfloat) file_data->total_size * file_data->total_time)
                 / file_data->cur_size;
@@ -482,8 +442,11 @@ download_info_update_statistics (FileData *file_data)
 }
 
 void
-download_info_update (FileData *file_data)
+download_info_update ()
 {
+    FileData *file_data =
+        file_list_get_unique_selection (GTK_CLIST (dl_file_list));
+    
     /* Check if we have data to put on download info page */
     if (file_data == NULL) {
         /* Clear the download info page */
@@ -491,7 +454,7 @@ download_info_update (FileData *file_data)
 	gtk_label_set_text (GTK_LABEL (info.file), "");
 	gtk_label_set_text (GTK_LABEL (info.size), "");
 	gtk_label_set_text (GTK_LABEL (info.state), "");
-        gtk_progress_set_value (GTK_PROGRESS (info.retr_progress), 0);
+        gtk_widget_hide (info.retr_progress);
 	gtk_label_set_text (GTK_LABEL (info.retrieved), "");
 	gtk_label_set_text (GTK_LABEL (info.estimated), "");
 	gtk_label_set_text (GTK_LABEL (info.remain), "");
@@ -522,6 +485,15 @@ download_info_update (FileData *file_data)
         gtk_toggle_button_set_active 
             (GTK_TOGGLE_BUTTON (info.use_proxy),
              file_data->use_proxy);
+        
+        /* Hide the progress bar if state is not started or completed or 
+           total size is 0 and show it otherwise */
+        if (file_data->state == DL_NOT_STARTED
+            || file_data->state == DL_COMPLETED
+            || file_data->total_size == 0)
+            gtk_widget_hide (info.retr_progress);
+        else
+            gtk_widget_show (info.retr_progress);
 
         /* Update the state of the toggle auto download button on the toolbar
            and menu */
