@@ -136,6 +136,10 @@ file_data_set_state (FileData *file_data, DlState state, gboolean sync)
         download_info_update ();
         dialog_prop (FALSE);
     }
+    if (state == DL_COMPLETED 
+	&& !file_list_has_pending_work (GTK_CLIST (file_data->file_list))) {
+	report_event ("all_complete");
+    }
 }
 
 void
@@ -184,7 +188,52 @@ int
 file_data_url_valid (const gchar *url)
 {
     return (strncasecmp (url, "http://", 7) == 0 ||
-            strncasecmp (url, "ftp://", 6) == 0 );
+            strncasecmp (url, "ftp://", 6) == 0 ||
+#ifdef ENABLE_SSL
+	    strncasecmp (url, "https://", 8) == 0
+#else
+	    FALSE
+#endif
+	);
+}
+
+/* return true if dir exists and is writable */
+int
+file_data_dir_valid (const gchar *dir)
+{
+    struct stat st;
+    static int euid = -1;
+    int mode = 0;
+    static gid_t groups[100];
+    static int n_groups = -1;
+    int i;
+    
+    g_return_val_if_fail (*dir != '\0', FALSE);
+
+    if (stat (dir, &st) < 0)
+	return FALSE;
+
+    if (!S_ISDIR (st.st_mode))
+	return FALSE;
+    
+    if (euid == -1)
+	euid = geteuid ();
+
+    if (n_groups == -1) {
+        n_groups = getgroups (100, groups);
+    }
+
+    if (euid == 0)
+	return TRUE; /* root can write anywhere */
+    if (st.st_uid == euid)
+	mode |= (2 << 6); /* owner of dir */
+    if (st.st_gid == getegid ())
+	mode |= (2 << 3); /* in dir's group */
+    for (i = 0; i < n_groups; i++)
+        if (st.st_gid == groups[i])
+            mode |= (2 << 3); /* in dir's group */
+            
+    return (st.st_mode & mode);
 }
 
 void file_data_set_use_proxy (FileData *file_data,
@@ -279,7 +328,7 @@ file_data_process_information (FileData *file_data)
     /* Check that wget process is still running */
     child_pid = waitpid (file_data->wget_pid, &status, WNOHANG | WUNTRACED);
     if (child_pid == file_data->wget_pid) {
-	/* Wget process stopped so we must register it's exit */
+	/* Wget process stopped so we must register its exit */
 	close (file_data->log_fd);
 	g_free (file_data->line);
 	file_data->line = NULL;
@@ -344,7 +393,7 @@ file_data_start_download (FileData *file_data)
             argv[6] = "-t";                   /* Number of retries */
             argv[7] = g_strdup_printf ("%d", gtm_pref.num_retries);
             argv[8] = "-T";                   /* Wget timeout */
-            argv[9] = "30";                   /* The value is hardwired! */
+            argv[9] = g_strdup_printf ("%d", gtm_pref.read_timeout);
             arg = 10;
 
             /* Proxy arguments */
@@ -362,7 +411,7 @@ file_data_start_download (FileData *file_data)
                                                gtm_pref.proxy_pass, 
                                                NULL);
 
-                /* Proxy location defined with environment variables */
+                /* Proxy locations defined with environment variables */
                 if (gtm_pref.proxy_http[0] != '\0') {
                     opt = g_strconcat ("http_proxy=", gtm_pref.proxy_http,
                                        NULL);
@@ -371,12 +420,21 @@ file_data_start_download (FileData *file_data)
                      * environment */
                 }
                 if (gtm_pref.proxy_http[0] != '\0') {
-                    opt = g_strconcat ("ftp_proxy=", gtm_pref.proxy_http,
+                    opt = g_strconcat ("ftp_proxy=", gtm_pref.proxy_ftp,
                                        NULL);
                     putenv (opt);
                     /* opt is not freed because it is incorporated on the
                      * environment */
-                } 
+                }
+#ifdef ENABLE_SSL
+		if (gtm_pref.proxy_https[0] != '\0') {
+		    opt = g_strconcat ("https_proxy=", gtm_pref.proxy_https,
+				       NULL);
+		    putenv (opt);
+                    /* opt is not freed because it is incorporated on the
+                     * environment */
+		}
+#endif
             } else
                 argv[arg++] = "off";
 
@@ -387,9 +445,9 @@ file_data_start_download (FileData *file_data)
             /* We must terminate the arguments with a NULL entry */
             argv[arg] = NULL;
 
-            /* Set Language to en_US. This must be done or we will not be able
+            /* Set Language to C. This must be done or we will not be able
              * to parse the wget output */
-            putenv ("LC_ALL=en_US");
+            putenv ("LC_ALL=C");
 
             /* Everything ready run wget */
             execvp ("wget", argv);
