@@ -399,6 +399,9 @@ file_list_create (void)
         { "text/plain", 0, TARGET_URL },
         { "x-url/http", 0, TARGET_NETSCAPE_URL },
         { "x-url/ftp", 0, TARGET_NETSCAPE_URL },
+#ifdef ENABLE_SSL
+	{ "x-url/https", 0, TARGET_NETSCAPE_URL },
+#endif
         { "_NETSCAPE_URL", 0, TARGET_NETSCAPE_URL }
     };
 
@@ -412,7 +415,7 @@ file_list_create (void)
     /* This panel data is used for drag auto-scroll */
     panel = g_new (Panel, 1);
 
-    /* Create the clist and set it's attributes */
+    /* Create the clist and set its attributes */
     for (i = 0; i < FILE_LIST_TOTAL_COLUMNS; i++)
         t_titles[i] = _ (titles[i]);
     file_list = gtk_clist_new_with_titles (4, t_titles);
@@ -614,41 +617,63 @@ file_list_find_url (GtkCList *file_list, gchar *url)
     return -1;
 }
 
-static gboolean
+static AddResult
 file_list_simple_add (GtkCList *file_list, FileData *file_data, 
                       gboolean check_duplicates)
 {
     gint row;
     gchar *data[FILE_LIST_TOTAL_COLUMNS];
-    gchar *local_file;
-    GtkWidget *error;
     FILE *fp;
+    GtkWidget *label;
 
     /* Check if the URL is not on the file list */
     if (check_duplicates &&
-        (file_list_find_url (file_list, file_data->url) != -1))
-	return FALSE;
+        (file_list_find_url (file_list, file_data->url) != -1)) {
+	return ADD_FAIL_DUPLICATE;
+    }
 
     /* Check if in the download directory there already is a */
     /* file with the same name                              */
-    local_file = g_strconcat (file_data->dir, file_data->filename, NULL);
-    fp = fopen (local_file, "r");
+    fp = fopen (file_data->local_filename, "r");
     if (check_duplicates && fp != NULL && file_data->state != DL_COMPLETED) {
 	gchar *error_msg;
-
+	GtkWidget *error;
+	int button;
+	
 	fclose(fp);
-
+	
 	error_msg = 
-            g_strconcat (_ ("File:\n"), local_file, "\n",
-                         _ ("already exists and it was replaced."),
+            g_strconcat (_ ("File:\n"), file_data->local_filename, "\n",
+                         _ ("already exists."),
                          NULL);
-        error = gnome_error_dialog_parented (error_msg, 
-                                                GTK_WINDOW (gtm_app));
-	gnome_dialog_run_and_close (GNOME_DIALOG (error));
+	error = gnome_dialog_new (_ ("File already exists"),
+				  _ ("Delete Existing File"),
+				  _ ("Attempt to Resume"),
+				  GNOME_STOCK_BUTTON_CANCEL,
+				  NULL);
+	label = gtk_label_new (_ ("A file of the same name already exists "
+				  "in the target directory."));
+	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (error)->vbox), 
+			    label, TRUE, TRUE, 0);
+	gtk_widget_show (label);
+	
+	gnome_dialog_set_parent (GNOME_DIALOG (error), GTK_WINDOW (gtm_app));
+	button = gnome_dialog_run_and_close (GNOME_DIALOG (error));
+
 	g_free (error_msg);
-        unlink (local_file);
+
+	switch (button) {
+	case 0: /* delete */
+	    unlink (file_data->local_filename);
+	    break;
+	case 1: /* resume */
+	    /* do nothing */
+	    break;
+	case 2: 
+	default: /* cancel, or close dialog with wm */
+	    return ADD_FAIL_FILE_EXISTS;
+	}
     }
-    g_free (local_file);
 
     file_data->file_list = GTK_WIDGET (file_list);
     data[FILE_LIST_COL_STATE] = NULL;
@@ -661,21 +686,24 @@ file_list_simple_add (GtkCList *file_list, FileData *file_data,
     file_data_set_state (file_data, file_data->state, FALSE);
     file_data_set_total_size (file_data, file_data->total_size, FALSE);
     file_data_update_statistics (file_data, FALSE);
-    return TRUE;
+    return ADD_OK;
 }
 
-gboolean
+gint
 file_list_single_add (GtkCList *file_list, FileData *file_data)
 {
-    if (!file_list_simple_add (GTK_CLIST (file_list), file_data, TRUE))
-        return FALSE;
+    gint result;
+
+    result = file_list_simple_add (GTK_CLIST (file_list), file_data, TRUE);
+    if (result != ADD_OK)
+        return result;
 
     file_list_update_statistics (GTK_CLIST (file_list));
     report_event ("add");
 
     gnome_config_sync ();
 
-    return TRUE;
+    return result;
 }
 
 gboolean
@@ -699,8 +727,8 @@ file_list_bulk_add (GtkCList *file_list, FileData **file_data_array,
     /* Add the URLs */
     for (file_num = 0; file_num < total_files; file_num++) {
         file_data = file_data_array[file_num];
-
-	file_list_simple_add (file_list, file_data, FALSE);
+	if (file_data)
+	    file_list_simple_add (file_list, file_data, FALSE);
     }
 
     gtk_clist_thaw (GTK_CLIST (dl_file_list));
@@ -808,10 +836,17 @@ file_list_load_old_format_data (GtkCList *file_list, gint total_files)
         file_data = g_new (FileData, 1);
         prefix = g_strdup_printf ("/gtm/File%d/", i);
         gnome_config_push_prefix (prefix);
-        file_data->id = next_file_id++;
         file_data->log_tag = -1;
         file_data->url = gnome_config_get_string ("url");
         file_data->dir = gnome_config_get_string ("dir");
+	if (file_data->url == NULL || file_data->dir == NULL ||
+	    strlen (file_data->url) < 1 || strlen (file_data->dir) < 1) {
+	    g_free (file_data);
+	    g_free (prefix);
+	    gnome_config_pop_prefix();
+	    continue;
+	}
+        file_data->id = next_file_id++;
         filename = &file_data->url[strlen (file_data->url)];
         while (*filename != '/' && filename != file_data->url)
             filename--;
@@ -893,7 +928,7 @@ file_list_load_data (GtkCList *file_list)
             /* New list format */
             next_file_id = gnome_config_get_int ("next_file_id=0");
             gnome_config_get_vector ("file_ids", &total_files, &files);
-	    file_data_array = g_new (FileData *, total_files);
+	    file_data_array = g_new0 (FileData *, total_files);
 
             /* Check the file_ids for errors. The errors GTM generated are a
              * repeated 0 on the list and non existing 0 section */
@@ -928,12 +963,20 @@ file_list_load_data (GtkCList *file_list)
                 for (i = 0; i < total_files; i++) {
                     prefix = g_strdup_printf ("/gtm/File%s/", files[i]);
                     if (gnome_config_has_section (prefix)) {
-                        file_data = g_new (FileData, 1);
+                        file_data = g_new0 (FileData, 1);
                         gnome_config_push_prefix (prefix);
                         file_data->id = atoi (files[i]);
                         file_data->log_tag = -1;
                         file_data->url = gnome_config_get_string ("url");
                         file_data->dir = gnome_config_get_string ("dir");
+			if (file_data->url == NULL || file_data->dir == NULL ||
+			    strlen (file_data->url) < 1 ||
+			    strlen (file_data->dir) < 1) {
+			    g_free (file_data);
+			    g_free (prefix);
+			    gnome_config_pop_prefix();
+			    continue;
+			}
                         filename = &file_data->url[strlen (file_data->url)];
                         while (*filename != '/' && filename != file_data->url)
                             filename--;
@@ -993,6 +1036,20 @@ file_list_func_on_selection (GtkCList *file_list,
     gtk_clist_thaw (file_list);
 }
 
+gboolean
+file_list_has_pending_work (GtkCList *file_list) {
+    int row = 0;
+    FileData *file_data;
+
+    while ((file_data =
+	    gtk_clist_get_row_data (GTK_CLIST (file_list), row)) != NULL) {
+	if (file_data->state != DL_COMPLETED && file_data->use_auto_dl == TRUE)
+	    return TRUE;
+	++row;
+    }
+    return FALSE;
+}
+
 void
 file_list_start_auto_downloads (GtkCList *file_list)
 {
