@@ -32,7 +32,7 @@ void file_list_set_row_statistics (GtkCList *file_list, gint row,
 
 gint file_list_find_url (GtkCList *file_list, gchar *url);
 
-gboolean file_list_single_add (GtkCList *file_list, FileData *file_data);
+gint file_list_single_add (GtkCList *file_list, FileData *file_data);
 
 gboolean file_list_bulk_add (GtkCList *file_list, FileData **file_data,
                              gint total_files, gboolean list_load);
@@ -51,6 +51,8 @@ void file_list_start_auto_downloads (GtkCList *file_list);
 
 void file_list_stop_auto_downloads (GtkCList *file_list);
 
+gboolean file_list_has_pending_work (GtkCList *file_list);
+
 void file_list_select_all (GtkCList *file_list);
 
 void file_list_unselect_all (GtkCList *file_list);
@@ -75,4 +77,11 @@ typedef struct
     guint32 retrieved_running;
 } FileListStats;
 
+/* result of attempting to add a file to the list */
+typedef enum {
+    ADD_OK,
+    ADD_FAIL_DUPLICATE,
+    ADD_FAIL_FILE_EXISTS
+} AddResult;
+
 #endif /* _FILE_LIST_H */
