@@ -29,6 +29,7 @@
 #include "robot.xpm"
 #include "pause-robot.xpm"
 #include "dl-infopage.xpm"
+#include "num-dl.xpm"
 
 /* Download info page */
 static GtkWidget *download_info;
@@ -225,11 +226,6 @@ static GnomeUIInfo main_menu_file[] = {
       remove_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
       'D', GDK_CONTROL_MASK, NULL },
     GNOMEUIINFO_SEPARATOR,
-    { GNOME_APP_UI_ITEM, N_ ("_List Statistics..."),
-      N_ ("Show file list summary"),
-      stats_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
-      GNOME_STOCK_MENU_BOOK_YELLOW, 'L', GDK_CONTROL_MASK, NULL },
-    GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_MENU_EXIT_ITEM (quit_cmd, NULL),
     GNOMEUIINFO_END
 };
@@ -268,7 +264,7 @@ static GnomeUIInfo main_menu_download[] = {
     GNOMEUIINFO_SEPARATOR,
 #define MAIN_MENU_DOWNLOAD_PAUSE_AUTO_DL 4
     GNOMEUIINFO_TOGGLEITEM (N_ ("Pause Auto Dl"),
-                            N_ ("Pause robot starting the auto download"),
+                            N_ ("Pause all auto downloads"),
                             toggle_pause_auto_dl_cmd, pause_robot_xpm),
     GNOMEUIINFO_END
 };
@@ -279,10 +275,14 @@ static GnomeUIInfo main_menu_settings[] = {
 };
 
 static GnomeUIInfo main_menu_tools[] = {
-    GNOMEUIINFO_ITEM_STOCK (N_ ("_Numeric Download"),
-                            N_ ("Download a group of URLs differing by "
-                                "number"),
-                            num_down_cmd, GNOME_STOCK_MENU_BOOK_OPEN ),
+    { GNOME_APP_UI_ITEM, N_ ("_Statistics..."),
+      N_ ("Show file list summary"),
+      stats_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
+      GNOME_STOCK_MENU_BOOK_YELLOW, 'L', GDK_CONTROL_MASK, NULL },
+    GNOMEUIINFO_ITEM (N_ ("_Numeric Download..."),
+                      N_ ("Download a group of URLs differing by "
+                          "number"),
+                      num_down_cmd, num_dl_xpm),
     GNOMEUIINFO_END
 };
 	
@@ -331,7 +331,7 @@ static GnomeUIInfo main_toolbar[] = {
     GNOMEUIINFO_SEPARATOR,
 #define MAIN_TOOLBAR_PAUSE_AUTO_DL 8
     GNOMEUIINFO_TOGGLEITEM (N_ ("Pause Auto Dl"),
-                            N_ ("Pause robot starting the auto download"),
+                            N_ ("Pause all auto downloads"),
                             toggle_pause_auto_dl_cmd, pause_robot_xpm),
 #define MAIN_TOOLBAR_TOGGLE_AUTO_DL 9
     GNOMEUIINFO_TOGGLEITEM (N_ ("Toggle Auto Dl"),
