@@ -25,11 +25,17 @@ void menu_toolbar_set_state (GtkCList *file_list);
 
 void menu_toolbar_set_auto_dl (GtkCList *file_list);
 
+void menu_toolbar_update_pause_auto_dl (GtkCList *file_list);
+
+void main_window_update_auto_hide_dl_info_page (gboolean auto_hide,
+                                                guint timeout);
+
 GtkWidget *main_window_create (gchar *geometry);
 
 void toolbar_update_style (void);
 
-void main_window_update_dl_info_page_visibility (void);
+void main_window_set_dl_info_page_visibility (GtkCList *file_list, 
+                                              gboolean visible);
 
 void remove_cmd (GtkWidget *widget, gpointer data);
 
