@@ -19,7 +19,7 @@
 #include <config.h>
 #include <popt-gnome.h>
 #include <gnome.h>
-#include <libgnorba/gnorba.h>
+#include <liboaf/liboaf.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <signal.h>
 #include <stdio.h>
@@ -58,6 +58,10 @@ static gboolean startup;
 /* Variable holding the timeout id of the check network function */
 static gint check_network_timeout_id = -1;
 
+/* CORBA environment to store CORBA exceptions */
+CORBA_Environment ev;
+
+
 /* Session management */
 static gint 
 die (GnomeClient *client, gpointer client_data)
@@ -108,11 +112,13 @@ load_preferences (void)
         gtm_pref.proxy_pass = gnome_config_get_string ("proxy_pass=");
         gtm_pref.proxy_http = gnome_config_get_string ("proxy_http=");
         gtm_pref.proxy_ftp = gnome_config_get_string ("proxy_ftp=");
+	gtm_pref.proxy_https = gnome_config_get_string ("proxy_https=");
         gnome_config_clean_key ("use_proxy");
         gnome_config_clean_key ("proxy_user");
         gnome_config_clean_key ("proxy_pass");
         gnome_config_clean_key ("proxy_http");
         gnome_config_clean_key ("proxy_ftp");
+	/* note proxy_https was introduced later, so not needed here */
         gnome_config_private_set_bool ("use_proxy", gtm_pref.use_proxy);
         gnome_config_private_set_string ("proxy_user", gtm_pref.proxy_user);
         gnome_config_private_set_string ("proxy_pass", gtm_pref.proxy_pass);
@@ -124,6 +130,7 @@ load_preferences (void)
         gtm_pref.proxy_pass = gnome_config_private_get_string ("proxy_pass=");
         gtm_pref.proxy_http = gnome_config_private_get_string ("proxy_http=");
         gtm_pref.proxy_ftp = gnome_config_private_get_string ("proxy_ftp=");
+	gtm_pref.proxy_https = gnome_config_private_get_string ("proxy_https=");
     }
     gtm_pref.toolbar_style = 
 	gnome_config_get_int_with_default ("toolbar_style", &def);
@@ -135,6 +142,7 @@ load_preferences (void)
         gtm_pref.def_download_dir = gnome_util_user_home ();
     gtm_pref.file_list_refresh = 
 	gnome_config_get_int ("file_list_refresh=1000");
+    gtm_pref.read_timeout = gnome_config_get_int ("read_timeout=30");
     gtm_pref.num_retries = gnome_config_get_int ("num_retries=0");
     gtm_pref.interface = gnome_config_get_string ("interface=ppp0");
     gtm_pref.num_of_auto_download = 
@@ -183,6 +191,8 @@ load_preferences (void)
 	gnome_config_get_int_with_default ("presume_protocol", &def);
     if (def)
 	gtm_pref.presume_protocol = PROTOCOL_HTTP;
+    gtm_pref.command_all_complete =
+	gnome_config_get_string ("command_all_complete=");
     gtm_pref.load_pause_auto_dl =
         gnome_config_get_bool ("load_pause_auto_dl=FALSE");
     if (gtm_pref.load_pause_auto_dl)
@@ -201,6 +211,10 @@ load_preferences (void)
 
 
 /* CORBA functions */
+
+GTM_Download
+impl_GTM_Download__create (PortableServer_POA poa, CORBA_Environment *ev);
+
 static void
 Exception (CORBA_Environment *ev)
 {
@@ -219,8 +233,36 @@ Exception (CORBA_Environment *ev)
     }
 }
 
-GTM_Download
-impl_GTM_Download__create (PortableServer_POA poa, CORBA_Environment *ev);
+/* Test if gtm is already running */
+static gboolean 
+corba_server_is_running()
+{
+    CORBA_Object gtm_servant;
+
+    gtm_servant = oaf_activate ("repo_ids.has('IDL:gtm/download:1.0')", NULL,
+				OAF_FLAG_EXISTING_ONLY, NULL, &ev);
+    Exception(&ev);
+    return (!CORBA_Object_is_nil (gtm_servant, &ev));
+}
+
+
+/* Register GTM with OAF */
+static void 
+register_corba_server(CORBA_ORB orb) 
+{
+    CORBA_Object gtm_servant;
+    gchar *reg_id;
+    PortableServer_POA root_poa;
+    /* Register the gtm CORBA object */
+    root_poa = (PortableServer_POA) 
+	CORBA_ORB_resolve_initial_references (orb, "RootPOA", &ev);
+    gtm_servant = impl_GTM_Download__create (root_poa, &ev);
+    reg_id = oaf_make_registration_id("OAFIID:GNOME_GTM", g_getenv("DISPLAY"));
+    oaf_active_server_register (reg_id, gtm_servant);
+    PortableServer_POAManager_activate
+		(PortableServer_POA__get_the_POAManager (root_poa, &ev), &ev);
+    g_free(reg_id);
+}
 
 
 /* Functions to handle the signals */
@@ -282,7 +324,24 @@ check_network (gpointer data)
 
 #endif
 
-/* Report an event by playing a sound or/and beeping */
+/* Fork and run arbitrary shell command */
+void
+shell_command (gchar *command)
+{
+    pid_t pid;
+
+    pid = fork();
+    if (pid == 0) {
+	execlp ("sh", "sh", "-c", command, NULL);
+	perror ("Failed to execute command");
+	exit (1);
+    }
+    if (pid < 0) {
+	perror ("Fork failed");
+    }
+}
+
+/* Report an event (play sound, beep, run command) */
 void
 report_event (gchar *which)
 {
@@ -292,6 +351,9 @@ report_event (gchar *which)
 
         if (gtm_pref.use_beep)
             gdk_beep ();
+	
+	if (strcmp (which, "all_complete") == 0)
+	    shell_command (gtm_pref.command_all_complete);
     }
 }
 
@@ -318,15 +380,12 @@ int
 main (int argc, char *argv[])
 {
     CORBA_ORB orb;
-    CORBA_Environment ev;
-    CORBA_Object gtm_servant;
-    PortableServer_POA root_poa;
-    PortableServer_POAManager pm;
     GnomeClient *client;
     gchar *geometry;
-    gint status;
     gchar *url_to_get = NULL;
     struct poptOption gtm_popt_options[] = {
+	{ NULL, '\0', POPT_ARG_INCLUDE_TABLE, &oaf_popt_options, 0, NULL,
+	  NULL },
         { "get-url", 'g', POPT_ARG_STRING, &url_to_get, 0,
           N_ ("url to fetch"), N_ ("URL")},
         { NULL, '\0', 0, NULL, 0 } /* end the list */
@@ -334,18 +393,21 @@ main (int argc, char *argv[])
     
     startup = TRUE;
 
+    /* Initialize CORBA and oaf */
     CORBA_exception_init (&ev);
 
+    /* Initialize the application and CORBA stuff */
+    gnome_init_with_popt_table ("gtm", VERSION, argc, argv,
+				gtm_popt_options, 0, NULL);
+
+    orb = oaf_init (argc, argv);
+
     /* Initialize the i18n stuff */
     bindtextdomain (PACKAGE, GNOMELOCALEDIR);
     textdomain (PACKAGE);
    
-    /* Initialize the application and CORBA stuff */
-    orb = gnome_CORBA_init_with_popt_table ("gtm", VERSION, &argc, argv,
-                                            gtm_popt_options, 0, NULL, 
-                                            GNORBA_INIT_SERVER_FUNC, &ev);
+
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/gtm.png");
-    Exception (&ev);
 
     /* If we have a URL from the command line connect to the running gtm
      * object and send him the URL to fetch */
@@ -353,14 +415,13 @@ main (int argc, char *argv[])
         GTM_Download gtm_download_client;
         gboolean result;
 
-        gtm_download_client = 
-            goad_server_activate_with_repo_id (NULL,
-                                               "IDL:gtm/download:1.0", 0,
-                                               NULL);
-
+	gtm_download_client = 
+	    oaf_activate_from_id ("OAFIID:GNOME_GTM", 
+		  		  0, NULL, &ev);
+	Exception(&ev);
         if (gtm_download_client != NULL) {
-            result = GTM_Download_add_url (gtm_download_client,
-                                           url_to_get, "", FALSE, FALSE, &ev);
+	  result = GTM_Download_add_url (gtm_download_client,
+	                                 url_to_get, "", FALSE, FALSE, &ev);
             if (ev._major != CORBA_NO_EXCEPTION)
                 g_printerr ("Exception thrown: %s\n", 
                             CORBA_exception_id (&ev));
@@ -407,35 +468,23 @@ main (int argc, char *argv[])
     signal (SIGTERM, signal_handler);
     signal (SIGHUP, signal_handler);
     signal (SIGPIPE, signal_handler);
-   
-    /* Register the gtm CORBA object */
-    root_poa = (PortableServer_POA) 
-	CORBA_ORB_resolve_initial_references (orb, "RootPOA", &ev);
-    Exception (&ev);
-    gtm_servant = impl_GTM_Download__create (root_poa, &ev);
-    Exception (&ev);
-    pm = PortableServer_POA__get_the_POAManager (root_poa, &ev);
-    Exception (&ev);
-    PortableServer_POAManager_activate (pm, &ev);
-    Exception (&ev);
-    status = goad_server_register (CORBA_OBJECT_NIL, gtm_servant, 
-				   "gtm_download", "object", &ev);
-    Exception (&ev);
-    
-    /* Check if we are not registering another gtm object */
-    if (status != 0) {
-	/* Another GTM is already running and has already registered it self
-	 * on the server */
-	GtkWidget *error;
 
-	error = gnome_error_dialog_parented (_ (
-	    "There is Another GNOME Transfer Manager running.\n"
-	    "Only one GNOME Transfer Manager can be running."), 
-                                             GTK_WINDOW (gtm_app) );
-	gnome_dialog_run_and_close (GNOME_DIALOG (error));
-	exit (1);
+    /* Test if another GTM is already running */
+    if (corba_server_is_running()) {
+        GtkWidget *error;
+        g_print("gtm already running");
+        error = gnome_error_dialog_parented (_ (
+		  "There is Another GNOME Transfer Manager running.\n"
+	          "Only one GNOME Transfer Manager can be running."), 
+	          GTK_WINDOW (gtm_app) );
+        gnome_dialog_run_and_close (GNOME_DIALOG (error));
+        exit (1);
     }
 
+
+    /* Register gtm with OAF */
+    register_corba_server(orb);
+
     /* Finished the startup */
     startup = FALSE;
 
