@@ -27,6 +27,7 @@
 #include "file-list.h"
 #include "wget-log.h"
 #include "download-info.h"
+#include "log.h"
 
 /* Function to convert the wget notation of file size (55,449,600) */ 
 static guint32 
@@ -48,20 +49,15 @@ convert_wget_size (char *size)
 static void
 show_error (FileData *file_data, gchar *error_msg)
 {
-    GtkWidget *error;
     gchar *message;
 
     /* Before showing the error message disable auto-download. If we don't do
      * this auto download retries to download the file again and with an error.
      */
     file_data_set_use_auto_dl (file_data, FALSE);
-    download_info_update(file_data);
-    message = g_strconcat (error_msg, file_data->url, NULL);
-    error = gnome_message_box_new (message, GNOME_MESSAGE_BOX_ERROR,
-				   GNOME_STOCK_BUTTON_OK, NULL);
+    message = g_strconcat (error_msg, "\t", file_data->url, NULL);
+    log_insert_entry (message);
     g_free (message);
-    gnome_dialog_set_close ((GnomeDialog *) error, TRUE);
-    gtk_widget_show (error);
 }
 
 
@@ -99,6 +95,10 @@ wget_log_process_line (FileData *file_data)
 	    else if (strstr (file_data->line, "Host not found.") != NULL)
 		show_error (file_data,
                             _ ("Host not found when downloading URL:\n"));
+	    else if (strstr (file_data->line, "unsupported protocol") != NULL)
+		show_error (file_data,
+			    _ ("Unsupported protocol - you need wget >= 1.7 "
+			       "for https:\n"));
 	    else
 		show_error (file_data,
                             _ ("Unknown error when downloading URL:\n"));
@@ -106,9 +106,10 @@ wget_log_process_line (FileData *file_data)
 	    return 1;
 	    break;
 
-	case DL_CONNECTED:
+        case DL_CONNECTED:
 	    /* File not found for FTP */
-	    if (strncmp (file_data->line, "No such file ", 13) == 0) {
+	    if (strncmp (file_data->line, "No such file ", 13) == 0 ||
+		strncmp (file_data->line, "No such dir", 11) == 0) {
 		show_error (file_data,
                             _ ("File not found when downloading URL:\n"));
 		break;
@@ -121,6 +122,14 @@ wget_log_process_line (FileData *file_data)
 		break;
 	    }
 
+	    /* local file conflicts */
+	    if (strstr (file_data->line, "Continued download fail") != NULL) {
+		show_error (file_data,
+			    _ ("Can't continue download, existing local file "
+			       "conflicts with remote file:\n"));
+		break;
+	    }
+
 	    /* Get the leght of file being downloaded */
 	    p = strstr (file_data->line, "Length: ");
 	    if (p != NULL) {
@@ -139,10 +148,36 @@ wget_log_process_line (FileData *file_data)
 		    file_data->session_start_size = 0;
 		}
 		file_data->session_elapsed = 0;
-	    }
+	    } else {
+                /* We didn't get a length so, probably it's unspecified size
+                   so get the start of download by trying to catch the
+                   string "K ->" */
+                p = strstr (file_data->line, "K -> ");
+                if (p != NULL) {
+                    /* Unspecified size, so set total_size to 0 */
+                    file_data_set_total_size (file_data, 0, TRUE);
+                    file_data_set_state (file_data, DL_RETRIEVING, TRUE);
+                    if (stat (file_data->local_filename, &file_stat) != -1) {
+                        file_data->session_start_time = file_stat.st_ctime;
+                        file_data->session_start_size = file_stat.st_size;
+                    } else {
+                        file_data->session_start_time = 0;
+                        file_data->session_start_size = 0;
+                    }
+                }
+                file_data->session_elapsed = 0;
+            }
 	    break;
 
-	default:
+        case DL_RETRIEVING:
+	    if (strncmp (file_data->line, "Cannot write to ", 15) == 0) {
+		show_error (file_data,
+			    _ ("Can't write to target directory:\n"));
+		kill (file_data->wget_pid, SIGKILL);
+		return 1;
+		break;
+	    }
+        default:
 	    break;
     }
     return 0;
